@@ -6,10 +6,11 @@ use warnings;
 use Astro::Time;
 use Carp qw(croak);
 use vars qw($VERSION @EXPORT @EXPORT_OK);
-$VERSION = 0.038;
+$VERSION = 0.04;
 use Exporter qw(import);
 @EXPORT = qw(ymdhms2lst datetime2lst filestat2lst now2lst time2lst);
-@EXPORT_OK = qw(ymdhms_2_lst datetime_2_lst filestat_2_lst now_2_lst time_2_lst);
+@EXPORT_OK =
+  qw(ymdhms_2_lst datetime_2_lst filestat_2_lst now_2_lst time_2_lst);
 
 =head1 NAME
 
@@ -17,14 +18,14 @@ Time::LST - Convert date/time representations to local sidereal time via Astro-T
 
 =head1 VERSION
 
-This is documentation for Version 0.038 of Time::LST (2009.09.26).
+This is documentation for Version 0.04 of Time::LST (2020.02.28).
 
 =head1 SYNOPSIS
 
   use Time::LST qw(datetime2lst filestat2lst now2lst time2lst ymdhms2lst);
   
   $long = -3.21145; # London, in degrees
-  
+ 
   $lst_from_string = datetime2lst('1942:8:7T17:00:00', -3.21145, 'BST'); # note approx only for pre-1970
   $data_mod_lst    = filestat2lst('mod', 'valid_path_to_a_file', $long); # or filestat2lst('create', $path, $long)
   $now_as_lst      = time2lst(time(), $long);
@@ -69,17 +70,19 @@ A timezone string can be specified as an optional third value for accurate parsi
 =cut
 
 sub datetime2lst {
-   my ($str, $long, $tz) = @_;
-   croak __PACKAGE__, '::datetime2lst: Need a datetime string' if !$str;
-   require Date::Parse;
-   my @ari = Date::Parse::strptime($str);
-   croak __PACKAGE__, '::datetime2lst: Check datetime: the sent datetime did not parse' if ! scalar @ari;
-   pop @ari;
-   $ari[4] += 1;
-   $ari[5] += 1900 if $ari[5] < 1000;
-   return ymdhms2lst([reverse @ari], $long, $tz);
+    my ( $str, $long, $tz ) = @_;
+    croak __PACKAGE__, '::datetime2lst: Need a datetime string' if !$str;
+    require Date::Parse;
+    my @ari = Date::Parse::strptime($str);
+    croak __PACKAGE__,
+      '::datetime2lst: Check datetime: the sent datetime did not parse'
+      if !scalar @ari;
+    pop @ari;
+    $ari[4] += 1;
+    $ari[5] += 1900 if $ari[5] < 1000;
+    return ymdhms2lst( [ reverse @ari ], $long, $tz );
 }
-*datetime_2_lst = \&datetime2lst; # Alias
+*datetime_2_lst = \&datetime2lst;    # Alias
 
 =head2 filestat2lst
 
@@ -94,12 +97,15 @@ The path must be to a "real" file, not a link to a file.
 =cut
 
 sub filestat2lst {
-   my ($op, $path, $long, $tz) = @_;
-   croak __PACKAGE__, '::filestat_2_lst: First argument needs to be create or mod' if $op !~ /^c|m/i;
-   croak __PACKAGE__, '::filestat_2_lst: Invalid path to file' if !$path or !-e $path;
-   return time2lst( (stat($path))[ $op =~ /^c/i ? 10 : 9 ] , $long, $tz);
+    my ( $op, $path, $long, $tz ) = @_;
+    croak __PACKAGE__,
+      '::filestat_2_lst: First argument needs to be create or mod'
+      if $op !~ /^c|m/i;
+    croak __PACKAGE__, '::filestat_2_lst: Invalid path to file'
+      if !$path or !-e $path;
+    return time2lst( ( stat($path) )[ $op =~ /^c/i ? 10 : 9 ], $long, $tz );
 }
-*filestat_2_lst = \&filestat2lst; # Alias
+*filestat_2_lst = \&filestat2lst;    # Alias
 
 =head2 now2lst
 
@@ -112,7 +118,7 @@ Same as going: C<time2lst(time(), $long)>.
 =cut
 
 sub now2lst {
-    return time2lst(time(), @_);
+    return time2lst( time(), @_ );
 }
 *now_2_lst = \&now2lst;
 
@@ -133,36 +139,43 @@ A final timezone string - e.g., 'EST', 'AEDT' - is optional. Sending nothing, or
 =cut
 
 sub ymdhms2lst {
-   my ($ymdhms, $long, $tz) = @_;
-   croak __PACKAGE__, '::ymdhms2lst: Need an array reference to calculate LST' if ! ref $ymdhms;
-   croak __PACKAGE__, '::ymdhms2lst: Need an array reference of datetime (6 values) to calculate LST' if ! ref $ymdhms eq 'ARRAY' or scalar @{$ymdhms} != 6;
+    my ( $ymdhms, $long, $tz ) = @_;
+    croak __PACKAGE__, '::ymdhms2lst: Need an array reference to calculate LST'
+      if !ref $ymdhms;
+    croak __PACKAGE__,
+'::ymdhms2lst: Need an array reference of datetime (6 values) to calculate LST'
+      if !ref $ymdhms eq 'ARRAY'
+      or scalar @{$ymdhms} != 6;
 
-  # Ensure the year is epoch-able:
-   if ($ymdhms->[0] < 1970) {
+    # Ensure the year is epoch-able:
+    if ( $ymdhms->[0] < 1970 ) {
         $ymdhms->[0] = 1970;
-        if($ymdhms->[1] == 2 && $ymdhms->[2] == 29) {
+        if ( $ymdhms->[1] == 2 && $ymdhms->[2] == 29 ) {
             $ymdhms->[2] = 28;
         }
-   }
-   
-   if ($ymdhms->[0] > 2037) {
-        $ymdhms->[0] = 2037; 
-        if($ymdhms->[1] == 2 && $ymdhms->[2] == 29) {
+    }
+
+    if ( $ymdhms->[0] > 2037 ) {
+        $ymdhms->[0] = 2037;
+        if ( $ymdhms->[1] == 2 && $ymdhms->[2] == 29 ) {
             $ymdhms->[2] = 28;
         }
-   }
+    }
 
-   # Some module doesn't like "pseudo-octals" like 08, or 00, but another will need at least a 0; SO:
-   my $i;
-   for ($i = 0; $i < 6; $i++) {
-       $ymdhms->[$i] =~ s/^0+//;
-       $ymdhms->[$i] ||= 0;
-   }
+# Some module doesn't like "pseudo-octals" like 08, or 00, but another will need at least a 0; SO:
+    my $i;
+    for ( $i = 0 ; $i < 6 ; $i++ ) {
+        $ymdhms->[$i] =~ s/^0+//;
+        $ymdhms->[$i] ||= 0;
+    }
 
-   my $epoch = _ymdhms2epochsecs($ymdhms, $tz);
-   croak __PACKAGE__, '::ymdhms2lst: Check datetime: the sent datetime did not parse' if  ! defined $epoch;
-   return time2lst($epoch, $long, $tz); # knock off time, just do the LST conversion
-#
+    my $epoch = _ymdhms2epochsecs( $ymdhms, $tz );
+    croak __PACKAGE__,
+      '::ymdhms2lst: Check datetime: the sent datetime did not parse'
+      if !defined $epoch;
+    return time2lst( $epoch, $long, $tz )
+      ;    # knock off time, just do the LST conversion
+    #
 }
 *ymdhms_2_lst = \&ymdhms2lst;
 
@@ -175,70 +188,73 @@ Returns LST given seconds since the epoch. If you have a time in localtime forma
 =cut
 
 sub time2lst {
-   my ($time, $long, $tz) = @_;
-   croak __PACKAGE__, '::time2lst: Need longitude and time to calculate LST' if !$long || !$time;
-   my @time_ari = gmtime($time);
-   return _convert(
+    my ( $time, $long, $tz ) = @_;
+    croak __PACKAGE__, '::time2lst: Need longitude and time to calculate LST'
+      if !$long || !$time;
+    my @time_ari = gmtime($time);
+    return _convert(
         [
-           ($time_ari[5] + 1900), # year (ISO format)
-           ($time_ari[4] + 1),   # month
-           $time_ari[3],        # day of month
-           @time_ari[2, 1, 0]  # hours, minutes, seconds
+            ( $time_ari[5] + 1900 ),    # year (ISO format)
+            ( $time_ari[4] + 1 ),       # month
+            $time_ari[3],               # day of month
+            @time_ari[ 2, 1, 0 ]        # hours, minutes, seconds
         ],
         $long
-   );
+    );
 }
-*time_2_lst = \&time2lst; # Alias
-
+*time_2_lst = \&time2lst;               # Alias
 
 sub _ymdhms2epochsecs {
-   my ($ymdhms, $tz) = @_;
-   
-   # Get the epoch seconds of this datetime thing:
-   my $epoch;
-   #$tz ||= 'local'; # Date::Parse handles localtime more reliably than does DateTime
-   if ($tz =~ /^([A-Z]{3,5}|local)$/) { # e.g., 'AEDT', 'BST', 'local'
-       require Date::Parse;
-	   my $str = join':', (@{$ymdhms}[0 .. 5]); # all 6 els as a string
-       $epoch = Date::Parse::str2time($str, $tz);
-   }
-   elsif ($tz =~ /^[A-Z]/) {
-       require DateTime;
-	   my @dkeys = (qw/year month day hour minute second/);
-	   my $i = 0;
-       my $dt = DateTime->new( ( map { $dkeys[$i++] => $_ } @{$ymdhms} ), time_zone => $tz, );
-       $epoch = $dt->epoch();
-  }
-  else { # No timezone specification; use Time::Local
-    require Time::Local;
-    #$time = timelocal($sec,$min,$hour,$mday,$mon,$year);
-    $epoch = Time::Local::timelocal(reverse @{$ymdhms});
-  }
-  return $epoch;
+    my ( $ymdhms, $tz ) = @_;
+
+    # Get the epoch seconds of this datetime thing:
+    my $epoch;
+
+#$tz ||= 'local'; # Date::Parse handles localtime more reliably than does DateTime
+    if ( $tz =~ /^([A-Z]{3,5}|local)$/ ) {    # e.g., 'AEDT', 'BST', 'local'
+        require Date::Parse;
+        my $str = join ':', ( @{$ymdhms}[ 0 .. 5 ] );    # all 6 els as a string
+        $epoch = Date::Parse::str2time( $str, $tz );
+    }
+    elsif ( $tz =~ /^[A-Z]/ ) {
+        require DateTime;
+        my @dkeys = (qw/year month day hour minute second/);
+        my $i     = 0;
+        my $dt    = DateTime->new( ( map { $dkeys[ $i++ ] => $_ } @{$ymdhms} ),
+            time_zone => $tz, );
+        $epoch = $dt->epoch();
+    }
+    else {    # No timezone specification; use Time::Local
+        require Time::Local;
+
+        #$time = timelocal($sec,$min,$hour,$mday,$mon,$year);
+        $epoch = Time::Local::timelocal( reverse @{$ymdhms} );
+    }
+    return $epoch;
 }
 
 sub _convert {
-   my $ymdhms = shift;
-   return turn2str(   # Convert Julian day into fraction of a turn
-            mjd2lst(
-                cal2mjd( # Convert calendar date & time (dayfraction) into Julian Day, via Astro-Time:
-                    $ymdhms->[2], # $day
-                    $ymdhms->[1], # $month
-                    $ymdhms->[0], # $year
-                    hms2time(# Convert hours, minutes & seconds into day fraction (ut), via Astro-Time:
-                        $ymdhms->[3],
-                        $ymdhms->[4],
-                        $ymdhms->[5],,
-                    ),
-                ), 
-                str2turn(# Convert angle from string (in Degrees, not Hours) into fraction of a turn, via Astro-Time:
-                    shift,
-                    'D',
-                )
+    my $ymdhms = shift;
+    return turn2str(    # Convert Julian day into fraction of a turn
+        mjd2lst(
+            cal2mjd( # Convert calendar date & time (dayfraction) into Julian Day, via Astro-Time:
+                $ymdhms->[2],    # $day
+                $ymdhms->[1],    # $month
+                $ymdhms->[0],    # $year
+                hms2time( # Convert hours, minutes & seconds into day fraction (ut), via Astro-Time:
+                    $ymdhms->[3],
+                    $ymdhms->[4],
+                    $ymdhms->[5],,
+                ),
             ),
-       'H', # into 'H(ours)' (not D(egrees))
-       0 # 'No. sig. digits'
-   );
+            str2turn( # Convert angle from string (in Degrees, not Hours) into fraction of a turn, via Astro-Time:
+                shift,
+                'D',
+            )
+        ),
+        'H',          # into 'H(ours)' (not D(egrees))
+        0             # 'No. sig. digits'
+    );
 }
 
 1;
@@ -274,7 +290,7 @@ L<http://home.tiscali.nl/~t876506/TZworld.html> for valid timezone strings.
 
 Timezone handling might need higher sensitivity.
 
-Epoch-external periods merit a better solution than reduction to the minimum/maximum.
+A better solution than reducing times outside the epoch to the minimum/maximum.
 
 =head1 ACKNOWLEDGEMENT
 
@@ -284,7 +300,7 @@ The author of Astro::Time kindly looked over the basic conversion wrap-up. Any e
 
 =over 4
 
-=item Copyright (c) 2006-2008 R Garton
+=item Copyright (c) 2006-2020 Roderick Garton
 
 rgarton AT cpan DOT org
 
